# coding: utf-8

"""
    Guardrails Hub Types

    Data structures used in the Guardrails Hub

    The version of the OpenAPI document: 0.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SimpleTypes(str, Enum):
    """
    SimpleTypes
    """

    """
    allowed enum values
    """
    ARRAY = 'array'
    BOOLEAN = 'boolean'
    INTEGER = 'integer'
    NULL = 'null'
    NUMBER = 'number'
    OBJECT = 'object'
    STRING = 'string'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SimpleTypes from a JSON string"""
        return cls(json.loads(json_str))


